package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltAgreementDetails;
import com.bonus.material.settlement.service.ISltAgreementDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 结算协议详情Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "结算协议详情接口")
@RestController
@RequestMapping("/slt_agreement_details")
public class SltAgreementDetailsController extends BaseController {
    @Autowired
    private ISltAgreementDetailsService sltAgreementDetailsService;

    /**
     * 查询结算协议详情列表
     */
    @ApiOperation(value = "查询结算协议详情列表")
    @RequiresPermissions("settlement:details:list")
    @GetMapping("/list")
    public TableDataInfo list(SltAgreementDetails sltAgreementDetails) {
        startPage();
        List<SltAgreementDetails> list = sltAgreementDetailsService.selectSltAgreementDetailsList(sltAgreementDetails);
        return getDataTable(list);
    }

    /**
     * 导出结算协议详情列表
     */
    @ApiOperation(value = "导出结算协议详情列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:details:export")
    @SysLog(title = "结算协议详情", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出结算协议详情")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltAgreementDetails sltAgreementDetails) {
        List<SltAgreementDetails> list = sltAgreementDetailsService.selectSltAgreementDetailsList(sltAgreementDetails);
        ExcelUtil<SltAgreementDetails> util = new ExcelUtil<SltAgreementDetails>(SltAgreementDetails.class);
        util.exportExcel(response, list, "结算协议详情数据");
    }

    /**
     * 获取结算协议详情详细信息
     */
    @ApiOperation(value = "获取结算协议详情详细信息")
    @RequiresPermissions("settlement:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltAgreementDetailsService.selectSltAgreementDetailsById(id));
    }

    /**
     * 新增结算协议详情
     */
    @ApiOperation(value = "新增结算协议详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:details:add")
    @SysLog(title = "结算协议详情", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增结算协议详情")
    @PostMapping
    public AjaxResult add(@RequestBody SltAgreementDetails sltAgreementDetails) {
        try {
            return toAjax(sltAgreementDetailsService.insertSltAgreementDetails(sltAgreementDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改结算协议详情
     */
    @ApiOperation(value = "修改结算协议详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:details:edit")
    @SysLog(title = "结算协议详情", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改结算协议详情")
    @PutMapping
    public AjaxResult edit(@RequestBody SltAgreementDetails sltAgreementDetails) {
        try {
            return toAjax(sltAgreementDetailsService.updateSltAgreementDetails(sltAgreementDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除结算协议详情
     */
    @ApiOperation(value = "删除结算协议详情")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:details:remove")
    @SysLog(title = "结算协议详情", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除结算协议详情")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltAgreementDetailsService.deleteSltAgreementDetailsByIds(ids));
    }
}
